@@ -130,11 +130,13 @@ class Entity:
         for explicit_field in model_fields:
             if special_fields and explicit_field.name not in result:
                 raise Exception(
-                    "{}.{} is either (a) both excluded via AllModelFields's excluding keyword argument and included as a ModelField, or (b) reference a model that is not specified by an Entity.".format(
+                    "{}.{} (a) does not exist, or (b) both excluded via AllModelFields's excluding keyword argument and included as a ModelField, or (c) references a model that is not specified by an Entity.".format(
                         cls.Meta.model.__name__, explicit_field.name
                     )
                 )
-            result[explicit_field.name] = explicit_field
+            result[explicit_field.name] = explicit_field.with_model_class(
+                cls.Meta.model
+            )
 
         return result.values()
 
