@@ -1,4 +1,4 @@
-from ..util.query_optimization import get_prefetched_queryset
+from ..util.visitors import visit_query
 from ..util.arguments import (
     DEFAULT_MAXIMUM_RESULTS,
     ABSOLUTE_MAXIMUM_RESULTS,
@@ -11,9 +11,6 @@ def build_list_resolver(model_class, registry, related_name=None):
 
     def list_resolver(parent, info, **kwargs):
 
-        if not entity_class.is_readable_by_context(info.context):
-            raise Exception("Invalid permissions.")
-
         # If related_name and parent are not None, then we are resolving a
         # subselect, which has already been prefetched via the code below.
         if related_name and parent is not None:
@@ -53,7 +50,8 @@ def build_list_resolver(model_class, registry, related_name=None):
         # We're resolving a top-level select, so we must filter by org,
         # which is done by running the check lambda provided by the caller
         queryset = entity_class.get_queryset(info.context)
-        return get_prefetched_queryset(queryset, registry, info)
+        artifacts = visit_query(registry, info)
+        return artifacts["queryset_optimizer"].optimize(queryset)
 
     return list_resolver
 
