@@ -63,7 +63,7 @@ class AggregateBasicType(CacheableTypeBuilder, AbstractTypeBuilder):
                 )
                 aggregate_basic_type_attrs[
                     "resolve_{}".format(field_name)
-                ] = build_field_resolver(field)
+                ] = build_field_resolver(field, registry)
                 type_name = (
                     specialized_field_types_by_aggregate_field_name.get(
                         aggregate_field_name
@@ -81,7 +81,7 @@ class AggregateBasicType(CacheableTypeBuilder, AbstractTypeBuilder):
                 )
                 aggregate_basic_type_attrs[
                     "resolve_{}".format(field_name)
-                ] = build_field_resolver(field)
+                ] = build_field_resolver(field, registry)
                 type_name = field.field.get_internal_type()
                 graphene_type = registry.schema.FIELD_TYPE_MAP[type_name]
                 aggregate_basic_type_attrs["{}_id".format(field_name)] = graphene_type(
@@ -93,7 +93,7 @@ class AggregateBasicType(CacheableTypeBuilder, AbstractTypeBuilder):
                 )
                 aggregate_basic_type_attrs[
                     "resolve_{}".format(field_name)
-                ] = build_field_resolver(field)
+                ] = build_field_resolver(field, registry)
 
         result = type(
             "{}{}{}".format(
