@@ -1,5 +1,5 @@
 from ....abstract_type_builder import AbstractTypeBuilder, CacheableTypeBuilder
-from ...mappings import DJANGO_TYPE_NAMES_TO_GRAPHENE_TYPES, Types
+from ...mappings import Types
 from graphene import Field, ObjectType
 from ...resolvers.group_by import build_group_by_resolver
 
@@ -12,12 +12,10 @@ class AggregateGroupByType(CacheableTypeBuilder, AbstractTypeBuilder):
         entity_class = registry.get_entity_class(model_class)
 
         for model_field in registry.get_model_fields(model_class).values():
-            field = model_field.get_django_model_field(model_class)
+            field = model_field.get_django_model_field()
 
             if field.concrete and not field.is_relation:
-                attrs[field.name] = DJANGO_TYPE_NAMES_TO_GRAPHENE_TYPES[
-                    field.get_internal_type()
-                ]()
+                attrs[field.name] = registry.get_graphene_type_or_default(model_field)()
             elif field.concrete and field.is_relation:
                 # Example: model_class is Album, and field is Album.artist
                 attrs[field.name] = Field(
