@@ -51,7 +51,7 @@ class BasicType(CacheableTypeBuilder, AbstractTypeBuilder):
                 )
                 basic_type_attrs[
                     "resolve_{}".format(field.name)
-                ] = build_field_resolver(field)
+                ] = build_field_resolver(field, registry)
 
                 # If this relational field is concrete, also add a *_id property
                 # to the GraphQL type. I.e., a foo that has a bar will have both
