@@ -1,5 +1,4 @@
 from ....abstract_type_builder import AbstractTypeBuilder, CacheableTypeBuilder
-from ...mappings import DJANGO_TYPE_NAMES_TO_GRAPHENE_TYPES
 from graphene import Field, InputObjectType
 from djraphql.util.django_models import get_pk_fields_for_model
 
@@ -13,16 +12,14 @@ class PkInputType(CacheableTypeBuilder, AbstractTypeBuilder):
 
         if len(pk_fields) == 1:
             model_field = registry.get_model_fields(model_class)[pk_fields[0].name]
-            return model_field.get_graphene_type(
-                pk_fields[0].model, DJANGO_TYPE_NAMES_TO_GRAPHENE_TYPES
-            )
+            return registry.get_graphene_type_or_default(model_field)
 
         return type(
             "{}PKInputType".format(model_class.__name__),
             (InputObjectType,),
             {
                 field.name: Field(
-                    DJANGO_TYPE_NAMES_TO_GRAPHENE_TYPES[field.get_internal_type()],
+                    registry.schema.type_map[field.get_internal_type()],
                     required=True,
                 )
                 for field in pk_fields
