@@ -1,6 +1,6 @@
 from djraphql.util.django_models import get_target_field
 from ....abstract_type_builder import AbstractTypeBuilder, CacheableTypeBuilder
-from ...mappings import DJANGO_TYPE_NAMES_TO_GRAPHENE_TYPES, Types
+from ...mappings import Types
 from graphene import Field, InputObjectType
 
 
@@ -14,7 +14,7 @@ class UpdateInputType(CacheableTypeBuilder, AbstractTypeBuilder):
         model_class = kwargs["model_class"]
         entity_class = registry.get_entity_class(model_class)
         for model_field in registry.get_model_fields(model_class).values():
-            field = model_field.get_django_model_field(model_class)
+            field = model_field.get_django_model_field()
 
             # Don't allow updating the field is it is (part of) a PK,
             # or it's not included in the Entity.Meta.fields list,
@@ -40,8 +40,8 @@ class UpdateInputType(CacheableTypeBuilder, AbstractTypeBuilder):
                         field.related_model
                     )[get_target_field(field).name]
 
-                    graphene_type = reverse_model_field.get_graphene_type(
-                        field.related_model, DJANGO_TYPE_NAMES_TO_GRAPHENE_TYPES
+                    graphene_type = registry.get_graphene_type_or_default(
+                        reverse_model_field
                     )
                     input_class_attrs["{}_id".format(field.name)] = graphene_type()
                 continue
@@ -57,8 +57,8 @@ class UpdateInputType(CacheableTypeBuilder, AbstractTypeBuilder):
                         field.related_model
                     )[get_target_field(field).name]
 
-                    graphene_type = reverse_model_field.get_graphene_type(
-                        field.related_model, DJANGO_TYPE_NAMES_TO_GRAPHENE_TYPES
+                    graphene_type = registry.get_graphene_type_or_default(
+                        reverse_model_field
                     )
                     input_class_attrs["{}_id".format(field.name)] = graphene_type()
                 related_model = field.related_model
@@ -78,8 +78,8 @@ class UpdateInputType(CacheableTypeBuilder, AbstractTypeBuilder):
                 )
                 input_class_attrs[field.name] = Field(enum_type, required=False)
             else:
-                input_class_attrs[field.name] = model_field.get_graphene_type(
-                    model_class, DJANGO_TYPE_NAMES_TO_GRAPHENE_TYPES
+                input_class_attrs[field.name] = registry.get_graphene_type_or_default(
+                    model_field
                 )()
 
         return type(
