@@ -14,13 +14,12 @@ class WhereClause(CacheableTypeBuilder, AbstractTypeBuilder):
         for model_field in registry.get_model_fields(model_class).values():
             field = model_field.get_django_model_field()
 
-            if field.is_relation:
-                if field.many_to_one or field.one_to_many:
-                    where_input_type_attrs[field.name] = Field(
-                        registry.lambda_from_registry(
-                            field.related_model, Types.WHERE_CLAUSE_TYPE
-                        )
+            if field.many_to_one or field.one_to_many:
+                where_input_type_attrs[field.name] = Field(
+                    registry.lambda_from_registry(
+                        field.related_model, Types.WHERE_CLAUSE_TYPE
                     )
+                )
 
             if not field.concrete:
                 continue
